fs-hash
=======

Utilities to hash files and directories.

Health
------

Master
++++++

.. image:: https://git.unistra.fr/di/fs-hash/badges/master/pipeline.svg
   :target: https://git.unistra.fr/di/fs-hash/commits/master
   :alt: Tests

.. image:: https://git.unistra.fr/di/fs-hash/badges/master/coverage.svg
   :target: https://git.unistra.fr/di/fs-hash/commits/master
   :alt: Coverage


Develop
+++++++

.. image:: https://git.unistra.fr/di/fs-hash/badges/develop/pipeline.svg
   :target: https://git.unistra.fr/di/fs-hash/commits/develop
   :alt: Tests

.. image:: https://git.unistra.fr/di/fs-hash/badges/develop/coverage.svg
   :target: https://git.unistra.fr/di/fs-hash/commits/develop
   :alt: Coverage

